#
# spec file for package gle
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gle
%define lname   libgle3
Version:        3.1.2
Release:        1.2
Summary:        The GLE Tubing and Extrusion Library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            http://linas.org/gle/
#Git-Clone:     https://github.com/linas/glextrusion
Source:         https://github.com/linas/glextrusion/archive/refs/tags/%name-%version.tar.gz
Patch1:         gle-3.1.0-fltmax.diff
BuildRequires:  freeglut-devel
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xmu)

%description
The GLE Tubing and Extrusion Library is a graphics application
programming interface (API). The library consists of a number of C
language subroutines for drawing tubing and extrusions. The library is
distributed in source code form in a package that includes
documentation, a VRML proposal, make files, and full source code and
header files. It uses the OpenGL (TM) programming API to perform the
actual drawing of the tubing and extrusions.

%package -n %lname
Summary:        The GLE Tubing and Extrusion Library
Group:          System/Libraries

%description -n %lname
The GLE Tubing and Extrusion Library is a graphics application
programming interface (API). The library consists of a number of C
language subroutines for drawing tubing and extrusions. The library is
distributed in source code form in a package that includes
documentation, a VRML proposal, make files, and full source code and
header files. It uses the OpenGL (TM) programming API to perform the
actual drawing of the tubing and extrusions.

%package devel
Summary:        Development files for the GLE tubing and extrusion library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Provides:       libgle-devel = %version-%release
Obsoletes:      libgle-devel < %version-%release

%description devel
The GLE Tubing and Extrusion Library is a graphics application
programming interface (API). The library consists of a number of C
language subroutines for drawing tubing and extrusions. The library is
distributed in source code form in a package that includes
documentation, a VRML proposal, make files, and full source code and
header files. It uses the OpenGL (TM) programming API to perform the
actual drawing of the tubing and extrusions.

%prep
%autosetup -p0 -n glextrusion-%name-%version

%build
autoreconf -fi
%configure --disable-static
%make_build

%check
%make_build check

%install
%make_install
rm -rf "%buildroot/%_datadir/doc/gle" "%buildroot/%_libdir"/*.la

%ldconfig_scriptlets -n %lname

%files -n %lname
%doc COPYING doc/COPYING.artistic
%{_libdir}/lib*.so.*

%files devel
%doc AUTHORS README doc/html/*.jpg doc/html/*.gif doc/html/*.html doc/html/README doc/gle-*.lsm
%doc %{_mandir}/man3/*
%{_includedir}/GL
%{_libdir}/lib*.so

%changelog
* Thu Mar 28 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.1.2
  * Build system updates, compiler warning fixes [boo#1221689]
- Delete gle-3.1.0.diff (partially merged)
* Tue Feb 27 2024 Jan Engelhardt <jengelh@inai.de>
- Use SRPM base name for subpackages like -devel.
- Delete old specfile constructs.
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Fri Jan 16 2015 jengelh@inai.de
- Improve RPM group classification and summaries.
  Use pkgconfig() names to pull in build dependencies.
  Drop --with-pic as shared libs are implicitly PIC already.
* Tue Apr 23 2013 dimstar@opensuse.org
- Add libXmu-devel and libXi-devel BuildRequires: configure
  explicitly checks for the presence of those libraries.
* Sun Feb  5 2012 jengelh@medozas.de
- Remove redundant tags/sections
- Parallel build with %%_smp_mflags
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Mon May 18 2009 prusnak@suse.cz
- create libgle3 and libgle-devel packages conforming
  to shared library policy
* Mon Feb 25 2008 crrodriguez@suse.de
- fix library-without-ldconfig-post* errors
- spec file cleanup
* Fri Aug  3 2007 dmueller@suse.de
- update to 3.1.0:
  * alphablending support
* Tue Nov  7 2006 prusnak@suse.cz
- changed MAXFLOAT to FLT_MAX
* Tue Nov  7 2006 prusnak@suse.cz
- changed 1.0e50 constants to MAXFLOAT [#216971]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Thu Aug 14 2003 nadvornik@suse.cz
- added /usr/include/GL to filelist [#28806]
* Wed May 21 2003 ro@suse.de
- remove cvsignore files
- remove unpackaged files from buildroot
* Sun May 11 2003 ro@suse.de
- added libstdc++-devel to neededforbuild
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Apr 26 2002 coolo@suse.de
- use %%_libdir
* Mon Nov 26 2001 nadvornik@suse.cz
- update to 3.0.6:
  - C++ wrapper fixes
- set prefix to /usr
* Thu Nov 15 2001 nadvornik@suse.cz
- fixed to compile
* Thu Nov  8 2001 ro@suse.de
- use mesa-devel-packages in neededforbuild
* Tue Nov  6 2001 nadvornik@suse.cz
- fixed to compile with new automake
* Wed Jun  6 2001 nadvornik@suse.cz
- fixed to compile with new autoconf
* Thu Mar 15 2001 ro@suse.de
- changed neededforbuild <mesaglu> to <xf86glu>
- changed neededforbuild <mesaglu-devel> to <xf86glu-devel>
* Mon Mar 12 2001 nadvornik@suse.cz
- added mesaglut mesaglut-devel xf86 to neededforbuild
* Fri Mar  9 2001 ro@suse.de
- added mesaglu
* Wed Mar  7 2001 ro@suse.de
- changed neededforbuild <mesadev> to <mesa-devel>
* Mon Dec 18 2000 ro@suse.de
- bzipped source
- fixed to compile
* Mon Nov 20 2000 grimmer@suse.de
- initial package (version 0.3.0)
